# Manuel de configuration

La section suivante précise comment installer et configurer le module `PolarisPrestaConnector` avec votre backoffice Polaris.

*Pour connaître les possibilités du module, savoir si une donnée est synchronisée ou non, et dans quel sens, vous devez vous reporter au manuel technique.*

## Installation

### Association

Pour fonctionner, le module a besoin de se connecter aux API fournies par votre backoffice. L'association est le processus qui vous permet d'établir cette connexion.

Pour associer votre module, allez dans sa page de configuration accessible depuis l'écran de gestion des modules.

Si le module n'a jamais été associé ou détecte des identifiants périmés, alors il vous proposera automatiquement de procéder à une association avant de continuer avec la configuration du module ; autrement, si vous désirez procéder à une association manuelle, cliquez sur le bouton `désassocier`.

Pour associer votre module à votre installation Polaris, vous allez devoir effectuer les étapes suivantes :

1. **entrer votre numéro de licence Polaris.** Il s'agit d'une chaîne alphanumérique de la forme : "pl-p8-111-2222" ;
2. sur Polaris, dans `Système > Gestion des appareils` ; 
   1. **si votre site n'a jamais été paramétré :** cliquez sur "`nouveau prestataire`" en choisissant les API "`WebConnect`" ; choisissez les paramètres les plus adaptés pour votre site Internet (droits, données, ...) ; à l'issue de cette procédure, un code PIN vous sera remis ;
   2. **si votre site a déjà été paramétré :** choisissez son accès dans la liste, modifiez-le et cliquez sur le bouton "`ré-associer`" pour générer un nouveau code PIN ;

3. **reportez ensuite le code PIN sur Prestashop** ;



### Mise en place de la tâche automatisée

Le module est conçu pour se connecter au backoffice Polaris via une tâche automatisée qui appelle une URL spécifique sur le serveur. 

Il est donc nécessaire de mettre en place sur votre serveur un script qui appelle cette page à intervalle régulier, en général, toutes les 5 minutes.

Cette URL est protégée par un jeton d'accès afin de ne pas permettre à n'importe qui d'exécuter la synchronisation sur votre système. Consultez la page de configuration du module pour connaître l'URL exacte de la page à appeler.

D'une manière générale, si vous utilisez ``crontab`` *(linux)* pour mettre en place votre appel avec curl, l'appel devrait ressembler à ceci :

```bash
0,5,10,15,20,25,30,35,40,45,50,55 * * * * /usr/bin/curl -k --silent --output /dev/null https://monsite.com/module/polprestaconnector/cron?guard=XXXX
```



### Tests

Pour mener vos tests et notamment lors d'un premier raccordement avec votre backoffice, nous vous conseillons de procéder à vos tests sur un site de préproduction.

De même, sélectionnez les produits à publier sur le site Internet de manière raisonné en commençant par une ou deux références présentant des caractéristiques distinctes afin de pouvoir mesurer l'impact du choix de vos options. Avec peu de références, vous pourrez ajuster/supprimer et faire autant d'essais que vous le souhaitez jusqu'à trouver une configuration qui correspond à votre méthode de travail.

Enfin, prenez garde à peut-être désactiver l'exportation des clients si vous ne désirez pas polluer votre backoffice de clients de tests.



### Configuration générale

#### Options globales

* **Synchronisation activée :** le module vous permet d'activer ou de désactiver rapidement la synchronisation des données, afin, par exemple, de mettre en pause l'opération. Désactiver la synchronisation empêche toute communication entre le site et le backoffice Polaris, dans un sens, comme dans l'autre.
* **Mode de synchronisation :** il existe deux modes de synchronisation. Le mode basique importe seulement les stocks, les prix et les promotions alors que le mode complet créée et entretien les fiches produits : référence, nom, description, photos et classification. Consultez la documentation technique pour connaître la liste exhaustive des données entretenues dans chacun des deux modes. Quelque soit le mode, les données exportées (commandes, clients, ...) sont toujours les mêmes.

#### Paramètre du catalogue

* l'option **stock de sécurité** vous permet de soustraire une ou plusieurs pièces en stock de chaque taille afin d'être sûr de ne jamais être hors stock sur votre site : il s'agit d'un montant qui sera déduit du stock. Par exemple, si vous mettez "1" et que vous avez 4 pièces en stock sur la taille L, le site Internet pensera que vous n'en avez que 3.
* l'option **visibilité des produits en stock** vous permet de choisir s'il faut afficher les produits dans le catalogue ou les recherches lorsque ce dernier n'a plus de stock ; ou bien s'il vaut mieux cacher le produit. Un produit caché est toujours accessible via son URL pour ne pas nuire à votre référencement Internet.
* l'option **attributs discrimants** vous permet de choisir de créer un produit Prestashop pour chaque produit Polaris ou bien plutôt un produit Prestashop pour chaque couleur, ou matière différente. Sélectionnez alors les attributs qui sont discriminants d'un produit unique. Dans le doute, laissez tout décoché (cf. Manuel technique).
* l'option **mappage des attributs de produit** vous permet de faire correspondre chaque attribut Polaris à un groupe d'attributs Prestashop. Les attributs à l'intérieur de ce groupe sont créés automatiquement selon la nécessité. *Par exemple, vous sélectionnez "coloris" pour la couleur, le module créera chaque couleur : rouge, bleu, ...*
  Notez que si vous n'affectez pas de groupe d'attributs Prestashop en face d'un attribut Polaris, alors cette information ne sera pas synchronisée.
* l'option **mappage des caractéristiques de produit** est la même chose que l'option précédente, mais pour les caractéristiques des produits et non les groupes d'attributs.
* les **options d'importation de produits** vous permettent de choisir quelles sont les données mises à jour lors de la synchronisation dans le cadre d'une synchronisation complète. Cette section n'est pas disponible quand vous utilisez le mode basique.

#### Paramètres des commandes

* renseignez les références Polaris (code barre) qui seront utilisés pour désigner les frais de port et les frais d'emballage dans les ventes exportés vers Polaris dans les options **référence pour les frais de port** et **référence pour l'emballage**. Nous vous conseillons de choisir des produits de type service à cette fin.
* le **mapping des modes de règlements** vous permet de mapper les modes de règlement Prestashop avec ceux utilisés sous Polaris. En face de chaque mode de règlement Prestashop qui vous est présenté, renseignez le code de règlement Polaris à utiliser lors de l'exportation de la commande. Si aucun mode de règlement n'est précisé, c'est le catch-all (*) qui sera utilisé. Si le catch-all n'est pas non plus défini, alors la commande sera ignorée.


### Mappage des catégories

<TODO>



## Synchronisation du catalogue produits

La synchronisation du catalogue produits est réalisée à intervalles réguliers par une tâche automatisée installée automatiquement par le module ou appelée manuellement par une intervention externe *(cf. Installation)* à condition d'avoir préalablement paramétré le module dans le mode "`Synchronisation du catalogue & du stock`".

Pour les produits déjà existants, un bouton de synchronisation est ajouté dans la barre d'outils des fiches produits compatibles (à côté du bouton d'aide). Ce bouton vous permet de resynchroniser que ce produit afin de refléter des modifications récentes ou bien de vérifier que la synchronisation fonctionne bien.

### Audit et journalisation

La synchronisation produit un fichier d'audit par jour stocké dans le répertoire /var/logs de Prestashop. Il contient la journalisation des actions du module et vous pouvez consulter ce journal dans les options du module.

### Informations synchronisées

Vous pouvez sélectionner les informations à synchroniser dans l'onglet "Catalogue" de la page de configuration du module : référence, nom du produit, marques, etc...

Une donnée qui est synchronisée est systématiquement écrasée par sa valeur du backoffice Polaris lorsqu'elle existe et lorsque le module synchronise le produit. Dans le cas contraire, la donnée est simplement reportée à la création de la fiche produit sous Prestashop.

*🛈 Par sécurité, le module modifie la page d'édition des produits de Prestashop de sorte qu'il vous soit impossible de modifier par cet écran une donnée qui est maintenue à jour depuis votre backoffice, car celle-ci serait susceptible d'être remplacée vous faisant perdre vos modifications.* 

*Les champs gérés par le module sont grisés et de couleur orange, uniquement sur les produits créés et maintenus par le module.*



## Questions fréquentes

### Comment tout resynchroniser ?

Par défaut, le module ne resynchronise que les données ayant changé sur votre backoffice depuis la dernière synchronisation.

Vous pouvez toutefois indiquer au module de tout resynchroniser (tout le catalogue, les stocks et les prix) en cliquant sur le bouton "`Resynchroniser`" de la page de configuration du module.

La resynchronisation totale sera effectuée lors de la prochaine synchronisation programmée.

### Empêcher une fiche produit d'être synchronisé

Lorsque le module est paramétré pour synchroniser les fiches produits, une icône de verrouillage vous permet d'empêcher le module de modifier la fiche produit. Si l'icône est un cadenas rouge, alors le module ignorera cette fiche produit et se contentera d'en synchroniser que les prix et les stocks.

Pour changer le comportement pour cette fiche produit, cliquez sur l'icône pour verrouiller ou déverrouiller la fiche.

Notez que le verrouillage vous permet de libérer tous les champs en édition.

### Resynchroniser une fiche produit.

Lorsque le module est paramétré pour synchroniser les fiches produits, une icône de synchronisation apparaît sur sa fiche produit vous permettant de déclencher une resynchronisation de ce produit.

Cliquez sur l'icône pour déclencher la synchronisation de la fiche.

### Exporter ou réexporter une commande

Les commandes ne se réexporte jamais automatique si le module considère qu'il a déjà tenté de le faire, y compris en cas d'erreur.

Si vous désirez retenter l'exportation d'une commande vers votre backoffice, un bouton `Réexporter vers Polaris` est disponible sur la fiche de chaque commande.

L'exportation a alors lieu immédiatement et produit les mêmes effets en cas d'erreur ou de réussite (le statut de la commande est changé, une éventuelle erreur est journalisée dans le journal de Prestashop avec la cause de l'échec).
